@@ -60,7 +60,9 @@ sub import {
                      'where',
                       Block   $constraint
     ) {
-        qq{BEGIN{ Dios::Types::_define_subtype('$new_type', '$new_type_params', 'Is', '[$known_type]',  sub $constraint) }};
+        my $subtype_defn
+            = qq{Dios::Types::_define_subtype('$new_type', '$new_type_params', 'Is',        '[$known_type]',  sub $constraint) };
+        qq{if (((caller 0)[3]//q{}) =~ /\\b(?:un)?import\\Z/) { $subtype_defn }; BEGIN{ $subtype_defn }};
     }
 
 
@@ -71,7 +73,9 @@ sub import {
                         'of',
                    TypeSpec $known_type,
     ) {
-        qq{BEGIN{ Dios::Types::_define_subtype('$new_type', '$new_type_params', 'Is', '[$known_type]') }};
+        my $subtype_defn
+            = qq{Dios::Types::_define_subtype('$new_type', '$new_type_params', 'Is', '[$known_type]') };
+        qq{if (((caller 0)[3]//q{}) =~ /\\b(?:un)?import\\Z/) { $subtype_defn }; BEGIN{ $subtype_defn }};
     }
 
 ### IF KEYWORDS }
@@ -2089,6 +2093,11 @@ The optional C<where> constraint must be specified as a block of code,
 which is converted to a subroutine that is automatically passed to
 C<validate()> whenever the subtype is used.
 
+Subtype declarations are restricted to the lexical scope in which they
+are declared. However, if a subtype is declared within a subroutine
+named C<import> or C<unimport>, that subtype will also be exported when
+the corresponding module is loaded.
+
 B<Note:> if you want to use the other features of this module, but
 don't want the compile-time overheads of this keyword, use the
 L<Dios::Types::Pure> module instead.
